package sun.awt.windows;

import sun.java2d.windows.WindowsFlags;
import java.awt.RenderingHints;
import sun.awt.SunToolkit;
import java.util.Map;
import java.awt.Font;
import java.awt.Color;
import java.util.Arrays;
import java.util.HashMap;
import sun.util.logging.PlatformLogger;

final class WDesktopProperties
{
    private static final PlatformLogger log;
    private static final String PREFIX = "win.";
    private static final String FILE_PREFIX = "awt.file.";
    private static final String PROP_NAMES = "win.propNames";
    private long pData;
    private WToolkit wToolkit;
    private HashMap<String, Object> map;
    static HashMap<String, String> fontNameMap;
    
    private static native void initIDs();
    
    static boolean isWindowsProperty(String s) {
        return s.startsWith("win.") || s.startsWith("awt.file.") || s.equals("awt.font.desktophints");
    }
    
    WDesktopProperties(WToolkit wToolkit) {
        this.map = new HashMap();
        this.wToolkit = wToolkit;
        this.init();
    }
    
    private native void init();
    
    private String[] getKeyNames() {
        Object[] array = this.map.keySet().toArray();
        String[] a = new String[array.length];
        for (int i = 0; i < array.length; ++i) {
            a[i] = array[i].toString();
        }
        Arrays.sort(a);
        return a;
    }
    
    private native void getWindowsParameters();
    
    private synchronized void setBooleanProperty(String s, boolean b) {
        assert s != null;
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(s + "=" + String.valueOf(b));
        }
        this.map.put(s, Boolean.valueOf(b));
        return;
    }
    
    private synchronized void setIntegerProperty(String s, int n) {
        assert s != null;
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(s + "=" + String.valueOf(n));
        }
        this.map.put(s, Integer.valueOf(n));
        return;
    }
    
    private synchronized void setStringProperty(String s, String s2) {
        assert s != null;
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(s + "=" + s2);
        }
        this.map.put(s, s2);
        return;
    }
    
    private synchronized void setColorProperty(String s, int r, int g, int b) {
        assert s != null && r <= 255 && g <= 255 && b <= 255;
        Color color = new Color(r, g, b);
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(s + "=" + color);
        }
        this.map.put(s, color);
        return;
    }
    
    private synchronized void setFontProperty(String str, String s, int style, int n) {
        assert str != null && style <= 3 && n >= 0;
        String s2 = (String)WDesktopProperties.fontNameMap.get(s);
        if (s2 != null) {
            s = s2;
        }
        Font o = new Font(s, style, n);
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(str + "=" + o);
        }
        this.map.put(str, o);
        String string = str + ".height";
        Integer value = Integer.valueOf(n);
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(string + "=" + value);
        }
        this.map.put(string, value);
        return;
    }
    
    private synchronized void setSoundProperty(String s, String s2) {
        assert s != null && s2 != null;
        WDesktopProperties.WinPlaySound winPlaySound = new WDesktopProperties.WinPlaySound(s2);
        if (WDesktopProperties.log.isLoggable(PlatformLogger.Level.FINE)) {
            WDesktopProperties.log.fine(s + "=" + winPlaySound);
        }
        this.map.put(s, winPlaySound);
        return;
    }
    
    private native void playWindowsSound(String p0);
    
    synchronized Map<String, Object> getProperties() {
        ThemeReader.flush();
        this.map = new HashMap();
        this.getWindowsParameters();
        this.map.put("awt.font.desktophints", SunToolkit.getDesktopFontHints());
        this.map.put("win.propNames", this.getKeyNames());
        this.map.put("DnD.Autoscroll.cursorHysteresis", this.map.get("win.drag.x"));
        return (Map)this.map.clone();
    }
    
    synchronized RenderingHints getDesktopAAHints() {
        Object value = RenderingHints.VALUE_TEXT_ANTIALIAS_DEFAULT;
        Integer value2 = null;
        Boolean b = (Boolean)this.map.get("win.text.fontSmoothingOn");
        if (b != null && b.equals(Boolean.TRUE)) {
            Integer n = (Integer)this.map.get("win.text.fontSmoothingType");
            if (n == null || (int)n <= 1 || (int)n > 2) {
                value = RenderingHints.VALUE_TEXT_ANTIALIAS_GASP;
            }
            else if (WindowsFlags.isAutoScaling()) {
                value = RenderingHints.VALUE_TEXT_ANTIALIAS_ON;
            }
            else {
                Integer n2 = (Integer)this.map.get("win.text.fontSmoothingOrientation");
                if (n2 == null || (int)n2 != 0) {
                    value = RenderingHints.VALUE_TEXT_ANTIALIAS_LCD_HRGB;
                }
                else {
                    value = RenderingHints.VALUE_TEXT_ANTIALIAS_LCD_HBGR;
                }
                Integer n3 = (Integer)this.map.get("win.text.fontSmoothingContrast");
                if (n3 == null) {
                    value2 = Integer.valueOf(140);
                }
                else {
                    value2 = Integer.valueOf((int)n3 / 10);
                }
            }
        }
        RenderingHints o = new RenderingHints(null);
        o.put(RenderingHints.KEY_TEXT_ANTIALIASING, value);
        if (value2 != null) {
            o.put(RenderingHints.KEY_TEXT_LCD_CONTRAST, value2);
            return o;
        }
        return o;
    }
    
    static void access$000(WDesktopProperties wDesktopProperties, String s) {
        wDesktopProperties.playWindowsSound(s);
    }
    
    static {
        log = PlatformLogger.getLogger("sun.awt.windows.WDesktopProperties");
        initIDs();
        (WDesktopProperties.fontNameMap = new HashMap()).put("Courier", "Monospaced");
        WDesktopProperties.fontNameMap.put("MS Serif", "Microsoft Serif");
        WDesktopProperties.fontNameMap.put("MS Sans Serif", "Microsoft Sans Serif");
        WDesktopProperties.fontNameMap.put("Terminal", "Dialog");
        WDesktopProperties.fontNameMap.put("FixedSys", "Monospaced");
        WDesktopProperties.fontNameMap.put("System", "Dialog");
    }
    
    class WinPlaySound implements Runnable
    {
        String winEventName;
        
        WinPlaySound(String winEventName) {
            this.winEventName = winEventName;
        }
        
        @Override
        public void run() {
            WDesktopProperties.access$000(WDesktopProperties.this, this.winEventName);
        }
        
        @Override
        public String toString() {
            return "WinPlaySound(" + this.winEventName + ")";
        }
        
        @Override
        public boolean equals(Object o) {
            if (o == this) {
                return true;
            }
            try {
                return this.winEventName.equals(((WDesktopProperties.WinPlaySound)o).winEventName);
            }
            catch (Exception ex) {
                return false;
            }
        }
        
        @Override
        public int hashCode() {
            return this.winEventName.hashCode();
        }
    }
}
